Generating coefficient and conditional matrics for Gaussian Process(GP) model with Matern 2.5 or power exponential kernels.
Construct_G_W_W0_V(d, gamma, eta, kernel_type, is_initial)A list of GG, W, W0 and VV matrix.
A value of the distance between the sorted input.
A value of the range parameter for the covariance matrix.
The noise-to-signal ratio.
A character specifying the type of kernels of the input. matern_5_2 are Matern correlation with roughness parameter 5/2. exp is power exponential correlation with roughness parameter alpha=2. The default choice is matern_5_2.
A bolean variable. is_initial=TRUE means the matrics generated is for the inital state.
tools:::Rd_package_author("SKFCPD")
Maintainer: tools:::Rd_package_maintainer("SKFCPD")
Hartikainen, J. and Sarkka, S. (2010). Kalman filtering and smoothing solutions to temporal gaussian process regression models. Machine Learning for Signal Processing (MLSP), 2010 IEEE International Workshop, 379-384.
M. Gu, Y. Xu (2019), fast nonseparable Gaussian stochastic process with application to methylation level interpolation. Journal of Computational and Graphical Statistics, In Press, arXiv:1711.11501.
Campagnoli P, Petris G, Petrone S. (2009), Dynamic linear model with R. Springer-Verlag New York.