Updating the predictive distribution of the run length under the objective prior.
get_predictive_dist_KF_objective_prior(cur_input, cur_num_obs,
params, prev_L, d, gamma, model_type, mu, sigma_2, eta, kernel_type)get_predictive_dist_KF_objective_prior returns a list of updated predictive distribution of the run length under the objective prior.
A value of current observation.
A value of index for the current observation.
A list of current Kalman filter parameters.
A list of previous Kalman filter parameters.
A value of the distance between the sorted input.
A numeric variable of the range parameter for the covariance matrix.
A numeric variable that can take values of 0, 1 and 2. Model_type=0 stands for a GP model with unknown mean and known variance. Model_type=1 stands for a GP model with known mean and unknown variance. Model_type=2 stands for a GP model with unknown mean and unknown variance.
A vector of the mean parameter at each coordinate. Ignored when model_type = 0 or 2.
A vector of the variance parameter at each coordinate.
A vector of the noise-to-signal ratio at each coordinate
A character specifying the type of kernels of the input. matern_5_2 are Matern correlation with roughness parameter 5/2. exp is power exponential correlation with roughness parameter alpha=2.
tools:::Rd_package_author("SKFCPD")
Maintainer: tools:::Rd_package_maintainer("SKFCPD")
Fearnhead, P., & Liu, Z. (2007). On-line inference for multiple changepoint problem. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 69(4), 589-605.
Adams, R. P., & MacKay, D. J. (2007). Bayesian online changepoint detection. arXiv preprint arXiv:0710.3742.
Hartikainen, J. and Sarkka, S. (2010). Kalman filtering and smoothing solutions to temporal gaussian process regression models, Machine Learning for Signal Processing (MLSP), 2010 IEEE International Workshop, 379-384.