Updating the predictive distribution of the run length under the objective prior directly.
get_predictive_dist_direct_objective_prior(cur_input_seq, d, gamma, mu, sigma_2, eta)get_predictive_dist_direct_objective_prior returns the log likelihood of observations that follows Gaussian Process with Exponential kernel.
A vector of sequence of observations.
A value of the distance between the sorted input.
A numeric variable of the range parameter for the covariance matrix. The default value of gamma is 1.
A vector of the noise-to-signal ratio at each coordinate
A vector of the mean parameter at each coordinate. Ignored when model_type = 0 or 2.
A vector of the variance parameter at each coordinate.
tools:::Rd_package_author("SKFCPD")
Maintainer: tools:::Rd_package_maintainer("SKFCPD")
Williams, C. K., & Rasmussen, C. E. (2006). Gaussian processes for machine learning (Vol. 2, No. 3, p. 4). Cambridge, MA: MIT press.