Updating the Kalman filter parameters for Gaussian Process model with Matern 2.5 or power exponential kernels.
get_LY_online(cur_input, prev_param, eta, G_W_W0_V)get_LY_online returns a list of updated kalman filter parameters.
A value of current observation.
A list of previous Kalman filter parameters.
The noise-to-signal ratio.
A list of the coefficient and conditional matrics for Gaussian Process(GP) model. It's the output from the function Construct_G_W_W0_V
tools:::Rd_package_author("SKFCPD")
Maintainer: tools:::Rd_package_maintainer("SKFCPD")
Fearnhead, P., & Liu, Z. (2007). On-line inference for multiple changepoint problem. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 69(4), 589-605.
Adams, R. P., & MacKay, D. J. (2007). Bayesian online changepoint detection. arXiv preprint arXiv:0710.3742.
Hartikainen, J. and Sarkka, S. (2010). Kalman filtering and smoothing solutions to temporal gaussian process regression models, Machine Learning for Signal Processing (MLSP), 2010 IEEE International Workshop, 379-384.